==> campsite-2.5.1.tar.gz: campsite/implementation/management/priv/lang/sv/issues.php <==
<?php
regGS("Issue List", "Utgåvslista");
regGS("Name<BR><SMALL>(click to see sections)</SMALL>", "Namn<BR><SMALL>(klicka för att se sektioner)</SMALL>");
regGS("Published<BR><SMALL>(yyyy-mm-dd)</SMALL>", "Publicerad<BR><SMALL>(åååå-mm-dd)</SMALL>");
regGS("Delete issue $1", "Radera utgåva $1");
regGS("Publish articles", "Publicera artiklar");
regGS("Change issue status", "Ändra utgåvestatus");
regGS("You do not have the right to change issues.", "Du har inte rätt att ändra på utgåvor.");
regGS("Are you sure you want to change the issue $1 status from $2 to $3?", "Är du säker att du vill ändra status på utgåvan $1 från $2 till $3");
regGS("Add new translation", "Lägg till ny översättning");
regGS("You do not have the right to add issues.", "Du har inte rätt att lägga till utgåvor.");
regGS("The issue $1 has been successfuly added.", "Utgåvan $1 har lagts till framgångsrikt.");
regGS("The issue could not be added.", "Utgåvan kunde inte läggas till.");
regGS("Please check if another issue with the same number/language does not already exist.", "Var god kontrollera om en utgåva med samma nummer/språk redan finns");
regGS("Change issue details", "Ändra utgåvans detaljer");
regGS("You do not have the right to change issue details.", "Du har inte rätt att ändra utgåvedetaljer.");
regGS("Publication date<BR><SMALL>(yyyy-mm-dd)</SMALL>", "Publiceringsdatum<BR><SMALL>(åååå-mm-dd)</SMALL>");
regGS("Front Page Template", "Framsidesmall");
regGS("Issue $1 updated in publication $2", "Utgåva $1 updaterad i publikation $2");
regGS("You do not have the right to delete issues.", "Du har inte rätt att radera utgåvor.");
regGS("Are you sure you want to delete the issue $1?", "Är du säker på att du vill radera utgåvan $1?");
regGS("Deleting issue", "Raderar utgåva");
regGS("Use the structure of the previous issue", "Använd strukturen från föregående utgåva");
regGS("Copy the entire structure in all languages from the previous issue except for content.", "Kopiera hela strukturen på alla språk från den föregående utgåvan förutom innehåll.");
regGS("You may modify it later if you wish.", "Du kan ändra det senare om du vill.");
regGS("Create a new structure", "Skapa en ny struktur");
regGS("Create a complete new structure.", "Skapa en helt ny struktur.");
regGS("You must define an issue type for each language and then sections for them.", "Du måste definiera en utgåvetyp för varje språk och sedan sektioner i dem.");
regGS("Copy previous issue", "Kopiera föregående utgåva");
regGS("No previous issue.", "Ingen tidigare utgåva.");
regGS("Copy structure from issue nr $1", "Kopiera struktur från utgåva nr $1");
regGS("Copying previous issue", "Kopierar föregående utgåva");
regGS("New issue $1 from $2 in publication $3", "Ny utgåva $1 från $2 i publikation $3");
regGS("Adding new issue", "Lägger till ny utgåva");
regGS("Delete entry", "Radera post");
regGS("Issue Publishing Schedule", "Utgåvepubliceringsschema");
regGS("Invalid Input: $1", "Ogiltig inmatning: $1");
regGS("Issue Number", "Utgåva nummer");
regGS("Go To Sections", "Gå till sektioner");
regGS("Add Event", "Lägg till händelse");
?>

==> campsite-2.6.6.tar.gz: campsite/implementation/management/priv/lang/sv/issues.php <==
<?php 
regGS("Change issue status", "");
regGS("The values you are trying to set conflict with issue \"$1$2. $3 ($4)$5\".", "");
regGS("The number must be unique for each issue in this publication of the same language.", "");
regGS("The language and URL name must be unique for each issue in this publication.", "");
regGS("Issue created.", "Utgåvan skapad.");
regGS("Issue updated", "Utgåvan uppdaterad");
regGS("Could not save the changes to the issue.", "");
regGS("Unpublish on: $1", "");
regGS("There are $1 articles in this issue.", "");
regGS("The issue $1 has been deleted.", "");
regGS("Schedule", "Schema");
regGS("Publish on: $1", "Publicera: $1");
regGS("Publish Date $1", "Publiceringsdatum $1");
regGS("Deleted issue", "Raderade utgåva");
regGS("Delete issue", "Radera utgåva");
regGS("Click here to publish this issue", "Tryck här för att publicera denna utgåva");
regGS("A total of $1 articles were deleted.", "Totalt $1 artiklar raderades.");
regGS("Name<BR><SMALL>(click to see sections)</SMALL>", "Namn<BR><SMALL>(klicka för att se sektioner)</SMALL>");
regGS("Delete issue $1", "Radera utgåva $1");
regGS("Publish articles", "Publicera artiklar");
regGS("You do not have the right to change issues.", "Du har inte rätt att ändra på utgåvor.");
regGS("Are you sure you want to change the issue $1 status from $2 to $3?", "Är du säker att du vill ändra status på utgåvan $1 från $2 till $3");
regGS("Add new translation", "Lägg till ny översättning");
regGS("You do not have the right to add issues.", "Du har inte rätt att lägga till utgåvor.");
regGS("The issue $1 has been successfuly added.", "Utgåvan $1 har lagts till framgångsrikt.");
regGS("The issue could not be added.", "Utgåvan kunde inte läggas till.");
regGS("Change issue details", "Ändra utgåvans detaljer");
regGS("You do not have the right to change issue details.", "Du har inte rätt att ändra utgåvedetaljer.");
regGS("Publication date<BR><SMALL>(yyyy-mm-dd)</SMALL>", "Publiceringsdatum<BR><SMALL>(åååå-mm-dd)</SMALL>");
regGS("Front Page Template", "Framsidesmall");
regGS("Issue $1 updated in publication $2", "Utgåva $1 updaterad i publikation $2");
regGS("You do not have the right to delete issues.", "Du har inte rätt att radera utgåvor.");
regGS("Are you sure you want to delete the issue $1?", "Är du säker på att du vill radera utgåvan $1?");
regGS("Use the structure of the previous issue", "Använd strukturen från föregående utgåva");
regGS("Copy the entire structure in all languages from the previous issue except for content.", "Kopiera hela strukturen på alla språk från den föregående utgåvan förutom innehåll.");
regGS("You may modify it later if you wish.", "Du kan ändra det senare om du vill.");
regGS("Create a new structure", "Skapa en ny struktur");
regGS("Create a complete new structure.", "Skapa en helt ny struktur.");
regGS("You must define an issue type for each language and then sections for them.", "Du måste definiera en utgåvetyp för varje språk och sedan sektioner i dem.");
regGS("Copy previous issue", "Kopiera föregående utgåva");
regGS("No previous issue.", "Ingen tidigare utgåva.");
regGS("Copy structure from issue number $1", "Kopiera struktur från utgåva nr $1");
regGS("New issue $1 from $2 in publication $3", "Ny utgåva $1 från $2 i publikation $3");
regGS("Delete entry", "Radera post");
regGS("Issue Publishing Schedule", "Utgåvepubliceringsschema");
regGS("Invalid Input: $1", "Ogiltig inmatning: $1");
regGS("Issue Number", "Utgåva nummer");
regGS("Go To Sections", "Gå till sektioner");
regGS("There was an error reading the language parameter.", "Ett fel uppstod vid läsning av språkparametern.");
regGS("There was an error reading the publication parameter.", "Ett fel uppstod vid läsning av publikationsparametern.");
regGS("There was an error reading the issue parameter.", "Ett fel uppstod vid läsning av utgåveparametern.");
regGS("There was an error scheduling the $1 action on $2", "Ett fel uppstod när $1 schemalades $2");
regGS("The action scheduled on $1 could not be deleted.", "Händelsen schemalagd $1 kunde inte raderas.");
regGS("Add Event", "Lägg till händelse");
?>
